@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.98';
+  $CPAN::Perl::Releases::VERSION = '1.00';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -311,6 +311,10 @@ our $data =
     "tar.bz2" => "R/RJ/RJBS/perl-5.16.2.tar.bz2",
     "tar.gz" => "R/RJ/RJBS/perl-5.16.2.tar.gz",
   },
+  "5.16.3-RC1" => {
+    "tar.bz2" => "R/RJ/RJBS/perl-5.16.3-RC1.tar.bz2",
+    "tar.gz" => "R/RJ/RJBS/perl-5.16.3-RC1.tar.gz",
+  },
   "5.17.0" => {
     "tar.bz2" => "Z/ZE/ZEFRAM/perl-5.17.0.tar.bz2",
     "tar.gz" => "Z/ZE/ZEFRAM/perl-5.17.0.tar.gz",
@@ -459,7 +463,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.98
+version 1.00
 
 =head1 SYNOPSIS
 
